Modules
- common
- ports
- static_
updater - sync_
state - This module contains the
SyncStateenum, which represents the state of the gas price synchronization process when a new L2 block is received. - v0
- v1
SyncState enum, which represents the state of the gas price synchronization process when a new L2 block is received.